"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateMembershipToken = exports.findSecondaryMetadataCreatorsAddress = exports.findPayoutTicketAddress = exports.findTradeHistoryAddress = exports.findTreasuryOwnerAddress = exports.findVaultOwnerAddress = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const web3_js_1 = require("@solana/web3.js");
const consts_1 = require("../consts");
const VAULT_OWNER_PREFIX = 'mt_vault';
const HISTORY_PREFIX = 'history';
const PAYOUT_TICKET_PREFIX = 'payout_ticket';
const HOLDER_PREFIX = 'holder';
const SECONDARY_METADATA_CREATORS_PREFIX = 'secondary_creators';
const findVaultOwnerAddress = (mint, store) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(VAULT_OWNER_PREFIX), mint.toBuffer(), store.toBuffer()], new web3_js_1.PublicKey(consts_1.PROGRAM_ID));
exports.findVaultOwnerAddress = findVaultOwnerAddress;
const findTreasuryOwnerAddress = (treasuryMint, sellingResource) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(HOLDER_PREFIX), treasuryMint.toBuffer(), sellingResource.toBuffer()], new web3_js_1.PublicKey(consts_1.PROGRAM_ID));
exports.findTreasuryOwnerAddress = findTreasuryOwnerAddress;
const findTradeHistoryAddress = (wallet, market) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(HISTORY_PREFIX), wallet.toBuffer(), market.toBuffer()], new web3_js_1.PublicKey(consts_1.PROGRAM_ID));
exports.findTradeHistoryAddress = findTradeHistoryAddress;
const findPayoutTicketAddress = (funder, market) => {
    return web3_js_1.PublicKey.findProgramAddress([Buffer.from(PAYOUT_TICKET_PREFIX), funder.toBuffer(), market.toBuffer()], new web3_js_1.PublicKey(consts_1.PROGRAM_ID));
};
exports.findPayoutTicketAddress = findPayoutTicketAddress;
const findSecondaryMetadataCreatorsAddress = (metadata) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(SECONDARY_METADATA_CREATORS_PREFIX), metadata.toBuffer()], new web3_js_1.PublicKey(consts_1.PROGRAM_ID));
exports.findSecondaryMetadataCreatorsAddress = findSecondaryMetadataCreatorsAddress;
const validateMembershipToken = (connection, me, ta) => __awaiter(void 0, void 0, void 0, function* () {
    const edition = (yield mpl_token_metadata_1.Metadata.getEdition(connection, ta.data.mint));
    return edition.data.parent === me.pubkey.toString();
});
exports.validateMembershipToken = validateMembershipToken;
//# sourceMappingURL=index.js.map