"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const amman_1 = require("@metaplex-foundation/amman");
const src_1 = require("../src");
const utils_1 = require("./utils");
const actions_1 = require("./actions");
const transactions_1 = require("./transactions");
(0, utils_1.killStuckProcess)();
(0, tape_1.default)('create-secondary-metadata-creators: success', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { payer, connection, transactionHandler } = yield (0, actions_1.createPrerequisites)();
    const store = yield (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { metadata } = yield (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const creator = src_1.CreatorAccountData.fromArgs({
        address: payer.publicKey,
        share: 100,
        verified: false,
    });
    const { secondaryMetadataCreators, createSecondaryMetadataCreatorsTx } = yield (0, transactions_1.createSecondaryMetadataCreators)({
        test: t,
        transactionHandler,
        payer,
        connection,
        metadata,
        creators: [creator],
    });
    const createSecondaryMetadataCreatorsRes = yield transactionHandler.sendAndConfirmTransaction(createSecondaryMetadataCreatorsTx, [payer], amman_1.defaultSendOptions);
    (0, utils_1.logDebug)(`secondary-metadata-creators: ${secondaryMetadataCreators.toBase58()}`);
    (0, amman_1.assertConfirmedTransaction)(t, createSecondaryMetadataCreatorsRes.txConfirmed);
}));
(0, tape_1.default)('create-secondary-metadata-creators: empty creators', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { payer, connection, transactionHandler } = yield (0, actions_1.createPrerequisites)();
    const store = yield (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { metadata } = yield (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const creators = [];
    const { createSecondaryMetadataCreatorsTx } = yield (0, transactions_1.createSecondaryMetadataCreators)({
        test: t,
        transactionHandler,
        payer,
        connection,
        metadata,
        creators,
    });
    try {
        yield transactionHandler.sendAndConfirmTransaction(createSecondaryMetadataCreatorsTx, [payer], amman_1.defaultSendOptions);
        t.fail('expected transaction to fail');
    }
    catch (err) {
        (0, amman_1.assertError)(t, err, [/custom program error/i, /0x1791/i]);
    }
}));
//# sourceMappingURL=createSecondaryMetadataCreators.test.js.map